#include <Adafruit_GFX.h>         // Core graphics library
#include <Adafruit_ST7789.h> // Hardware-specific library for ST7789
#include <SdFat.h>                // SD card & FAT filesystem library
#include <Adafruit_SPIFlash.h>    // SPI / QSPI flash library
#include <Adafruit_ImageReader.h> // Image-reading functions
#include <basicMPU6050.h>

bool printout_C = false;
bool printout_D = false;
bool printout_H = false;
bool printout_S = false;


// Create instance
basicMPU6050<> imu;

// Comment out the next line to load from SPI/QSPI flash instead of SD card:
#define USE_SD_CARD
#define SD_CS    4 // SD card select pin
#define TFT_CS  10 // TFT select pin
#define TFT_DC   8 // TFT display/command pin
#define TFT_RST  9 // Or set to -1 and connect to Arduino RESET pin

#if defined(USE_SD_CARD)
SdFat                SD;         // SD card filesystem
Adafruit_ImageReader reader(SD); // Image-reader object, pass in SD filesys
#else
// SPI or QSPI flash filesystem (i.e. CIRCUITPY drive)
#if defined(__SAMD51__) || defined(NRF52840_XXAA)
Adafruit_FlashTransport_QSPI flashTransport(PIN_QSPI_SCK, PIN_QSPI_CS,
    PIN_QSPI_IO0, PIN_QSPI_IO1, PIN_QSPI_IO2, PIN_QSPI_IO3);
#else
#if (SPI_INTERFACES_COUNT == 1)
Adafruit_FlashTransport_SPI flashTransport(SS, &SPI);
#else
Adafruit_FlashTransport_SPI flashTransport(SS1, &SPI1);
#endif
#endif
Adafruit_SPIFlash    flash(&flashTransport);
FatFileSystem        filesys;
Adafruit_ImageReader reader(filesys); // Image-reader, pass in flash filesys
#endif

Adafruit_ST7789      tft    = Adafruit_ST7789(TFT_CS, TFT_DC, TFT_RST);
Adafruit_Image       img;        // An image loaded into RAM
int32_t              width  = 0, // BMP image dimensions
                     height = 0;

void setup() {
  Serial.begin(38400);
  while (!Serial)
    delay(10); // will pause Zero, Leonardo, etc until serial console opens

  //Initialize LCD Display
  tft.init(240, 240);           // Init ST7789 320x240
  // The Adafruit_ImageReader constructor call (above, before setup())
  // accepts an uninitialized SdFat or FatFileSystem object. This MUST
  // BE INITIALIZED before using any of the image reader functions!
  Serial.print(F("Initializing filesystem..."));
#if defined(USE_SD_CARD)
  // SD card is pretty straightforward, a single call...
  if (!SD.begin(SD_CS, SD_SCK_MHZ(10))) { // Breakouts require 10 MHz limit due to longer wires
    Serial.println(F("SD begin() failed"));
    for (;;); // Fatal error, do not continue
  }
#else
  // SPI or QSPI flash requires two steps, one to access the bare flash
  // memory itself, then the second to access the filesystem within...
  if (!flash.begin()) {
    Serial.println(F("flash begin() failed"));
    for (;;);
  }
  if (!filesys.begin(&flash)) {
    Serial.println(F("filesys begin() failed"));
    for (;;);
  }
#endif
  Serial.println(F("OK!"));
  ImageReturnCode stat; // Status from image-reading functions
  tft.fillScreen(ST77XX_BLACK);



  //Initialize Accelerometer
  imu.setup();
  imu.setBias();

  delay(100);
}

void loop() {
  imu.updateBias();
  ImageReturnCode stat; // Status from image-reading functions


  //CLUB//
  if ((imu.ax() <= -0.70) && (imu.ay() <= 0.10)) { //UPDATE YOUR SPECIFIC CLUB POSITION COORDINATES HERE
    //delay(500);
    while (printout_C == false) {
      tft.setRotation(2);
      stat = reader.drawBMP("/Club.bmp", tft, 0, 0);
      printout_C = true;
      printout_D = false;
      printout_H = false;
      printout_S = false;
    }
//    Serial.print("X: ");
//    Serial.println(imu.ax());
//    Serial.print("Y: ");
//    Serial.println(imu.ay());
//    Serial.print("Z: ");
//    Serial.println(imu.az());
//    Serial.println("Club!");
  }
  //HEART//
  else if ((imu.ax() >= 0.00) && (imu.ay() >= .60)) { //UPDATE YOUR SPECIFIC HEART POSITION COORDINATES HERE
    while (printout_H == false) {
      tft.setRotation(1);
      stat = reader.drawBMP("/Heart.bmp", tft, 0, 0);
      printout_H = true;
      printout_C = false;
      printout_D = false;
      printout_S = false;
    }
//    Serial.print("X: ");
//    Serial.println(imu.ax());
//    Serial.print("Y: ");
//    Serial.println(imu.ay());
//    Serial.print("Z: ");
//    Serial.println(imu.az());
//    Serial.println("Heart!");
  }
  //SPADE//
  else if ((imu.ax() >= 0.90) && (imu.ay() >= 0.00)) { //UPDATE YOUR SPECIFIC SPADE POSITION COORDINATES HERE
    while (printout_S == false) {
      tft.setRotation(4);
      stat = reader.drawBMP("/Spade.bmp", tft, 0, 0);
      printout_S = true;
      printout_C = false;
      printout_D = false;
      printout_H = false;
    }
//    Serial.print("X: ");
//    Serial.println(imu.ax());
//    Serial.print("Y: ");
//    Serial.println(imu.ay());
//    Serial.print("Z: ");
//    Serial.println(imu.az());
//    Serial.println("Spade!");
  }
  //DIAMOND//
  else if ((imu.ax() >= 0.03) && (imu.ay() <= -0.50) && (imu.az() < 0.00)) { //UPDATE YOUR SPECIFIC DIAMOND POSITION COORDINATES HERE
    while (printout_D == false) {
      tft.setRotation(3);
      stat = reader.drawBMP("/Diamond.bmp", tft, 0, 0);
      printout_C = false;
      printout_D = true;
      printout_H = false;
      printout_S = false;
    }
//    Serial.print("X: ");
//    Serial.println(imu.ax());
//    Serial.print("Y: ");
//    Serial.println(imu.ay());
//    Serial.print("Z: ");
//    Serial.println(imu.az());
//    Serial.println("Diamond!");
  }
  //OFF//
  if ((imu.az() > 0.00)) { //UPDATE YOUR SPECIFIC OFF POSITION COORDINATES HERE
    tft.fillScreen(ST77XX_BLACK);
    printout_C = false;
    printout_D = false;
    printout_H = false;
    printout_S = false;
    //        Serial.print("X: ");
    //        Serial.println(imu.ax());
    //        Serial.print("Y: ");
    //        Serial.println(imu.ay());
    //        Serial.print("Z: ");
    //        Serial.println(imu.az());
    //    Serial.println("Off!");
  }

  delay(500);
}
